import asyncio
from pyppeteer import launch
from pyppeteer_stealth import stealth
import win32api  # pip install pywin32
import win32con  # pip install win32con
import win32gui  # pip install win32gui

opt_chrome = {
    "devtools": True,
    'userDataDir': r'C:\Users\Administrator\Desktop\userdir',
    'executablePath': r'C:\Users\Administrator\AppData\Local\Google\Chrome\Application\chrome.exe',
    'headless': False,
    'dumpio': True,  # 减少内存消耗   set_launch = {}
    'args': [
        '--no-sandbox',  # 关闭沙盒
        '--disable-gpu',
        '--window-size=1400,950',  # 屏幕大小
        "--user-agent=Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.97 Safari/537.36",
        '--window-position=100,100'
    ],
}


async def main111():
    browser = await launch(opt_chrome)
    page = await browser.newPage()
    await stealth(page)  # 反扒库
    # await page.setViewport({"width": 1920, "height": 1080, "x": 100, "y": 100})
    await page.goto('https://creator.xiaohongshu.com/creator/home')

    for i in range(10):
        await asyncio.sleep(1)
        print("i            :", i)

    # # 隐藏 Windows 任务栏
    # hwnd = win32gui.FindWindow(None, 'Google Chrome')
    # win32gui.ShowWindow(hwnd, win32con.SW_HIDE)

    zzz = 1
    await asyncio.sleep(6666666666666666666)
    await browser.close()


if __name__ == '__main__':
    asyncio.get_event_loop().run_until_complete(main111())



import importlib
import os
import requests

from .fs import *  # 文件操作
from .to import *  # 数据转化
from .desc import *  # 装饰器
from .spider import *  # 爬虫
from .tool import *  # 常用工具
from .wind import *  # 操作系统方法

from .colors import *  # 颜色
from .eval_func_str import *  # eval_func_str

# import astmain_py777.astmain as __
# from astmain_py777.astmain import print
# __.print_hook = True
# print = __.print

print_hook = False
print_old = print


def print(*args, **kwargs):
    if print_hook == True:
        print_old("\033[36m", *args, **kwargs)
    if print_hook == False:
        print_old(*args, **kwargs)


# desc = import_module(".desc")

# desc = importlib.import_module(".desc", package="astmain_py777.astmain")


def test():
    print("test            :", 15160)



import asyncio
import datetime

from pyppeteer import launch

import win32api, win32gui, win32con  # pip  install     pywin32  可能会出现问题_请看README_后端py.md

__ = None

import astmain_py777.astmain as __  # 本地包


def bbb():
    # spider = __.spider.SPIDER
    wind_find_name = __.spider.SPIDER.wind_find_name
    obj1 = wind_find_name("Google")
    print("obj1                 :", obj1)

    import ctypes

    # ctypes.windll.user32.SendMessageW(obj1["hwnd"], 0x0112, 0xF020, 0)

    window_style = ctypes.windll.user32.GetWindowLongW(obj1["hwnd"], -16)  # -16 代表 GWL_STYLE
    window_style &= ~0x10000000  # 清除 WS_VISIBLE 标志位
    ctypes.windll.user32.SetWindowLongW(obj1["hwnd"], -16, window_style)

    ctypes.windll.user32.SetWindowPos(obj1["hwnd"], None, 100, -880, 0, 0, 0x0001)
    """
    好博客 https://blog.csdn.net/weixin_30314631/article/details/97574375
    hwnd 是要移动的窗口的句柄。
    hWndInsertAfter 设为 None 表示不改变窗口的插入顺序。
    x 和 y 设置为 100,表示将窗口的左上角移动到屏幕坐标 (100, 100)。
    cx 和 cy 设为 0 表示不改变窗口的大小。
    uFlags 设为 0x0001 表示只修改窗口的位置,不修改大小。
    """


if __name__ == '__main__':
    pass


    async def aaa():
        pass
        opt = dict(
            title="title222小许" + datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
            text="text2222",
            files=[r"C:\Users\Administrator\Desktop\111.png", r"C:\Users\Administrator\Desktop\222.png"],
            cookies_str="""[
    {
        "name": "abRequestId",
        "value": "a376129c-d49b-5bbc-a8f4-170cc4bfe129",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1751043092.862638,
        "sameSite": "unspecified"
    },
    {
        "name": "a1",
        "value": "1905a9c0831wg416b0zniax0jqghkn390f4cocqpf50000243666",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1751043093,
        "sameSite": "unspecified"
    },
    {
        "name": "webId",
        "value": "6e110199fae6482d9b9f8ba843732d83",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1751043093,
        "sameSite": "unspecified"
    },
    {
        "name": "websectiga",
        "value": "984412fef754c018e472127b8effd174be8a5d51061c991aadd200c69a2801d6",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1719771432,
        "sameSite": "unspecified"
    },
    {
        "name": "gid",
        "value": "yj820jSJyW8Dyj820jS8YiSAqyEk4yKD8uI34Ui0C8VAkS28xTIqjl888J4qKKK8yKqfJWW8",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1754072239.355501,
        "sameSite": "unspecified"
    },
    {
        "name": "xsecappid",
        "value": "xhs-pc-web",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1751048236,
        "sameSite": "unspecified"
    },
    {
        "name": "acw_tc",
        "value": "34c2c09702979dbc55eba1576545febc0fddd0a0fc0f0b928dd2a4fd5803e004",
        "domain": "www.xiaohongshu.com",
        "hostOnly": true,
        "path": "/",
        "secure": false,
        "httpOnly": true,
        "session": false,
        "expirationDate": 1719514031.519517,
        "sameSite": "unspecified"
    },
    {
        "name": "webBuild",
        "value": "4.23.1",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": true,
        "sameSite": "unspecified"
    },
    {
        "name": "sec_poison_id",
        "value": "3116f21d-6593-4b6a-a780-3ff76159bc1f",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1719512837,
        "sameSite": "unspecified"
    },
    {
        "name": "web_session",
        "value": "0400698e30a4ad561bd2d4e448344b3da94447",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": true,
        "httpOnly": true,
        "session": false,
        "expirationDate": 1751048248.987734,
        "sameSite": "unspecified"
    },
    {
        "name": "unread",
        "value": "{%22ub%22:%2266798188000000001e013457%22%2C%22ue%22:%22667d734b000000001c02806a%22%2C%22uc%22:25}",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": true,
        "sameSite": "unspecified"
    }
]""",
        )

        num = 0
        opt = __.to_obj_dict(opt)

        # spider = await spider_pyppeteer()
        # spider = await __.spider.spider_pyppeteer(**dict( x=300, y=1))
        # spider = await __.spider.spider_pyppeteer(**dict(x=0, y=-900 + 2))
        spider = await __.spider.spider_pyppeteer(**dict(x=-10, y=-900 + 999))
        page = spider.page
        # cookies登陆
        # await spider.web_goto_set_cookie("https://creator.xiaohongshu.com/publish/publish", __.to.JSON(opt.cookies_str))
        await spider.web_goto_set_cookie("https://creator.xiaohongshu.com", __.to.JSON(opt.cookies_str))
        await asyncio.sleep(0.1)
        await spider.web_goto("https://creator.xiaohongshu.com/publish/publish")
        for ele in range(10):
            await asyncio.sleep(1)
            print("循环ele                 :", ele + 1)
        num += 1
        bbb()
        print(num, "cookies登陆url                 :", 111)
        await __.tool_await(1)

        # 点击发布图文_上传图片
        await spider.web_await_click(css=".tab:nth-child(2)")
        await spider.web_await_input_files(css=".upload-input", files=opt.files)
        num += 1
        print(num, "点击发布图文_上传图片                 :")

        # 输入标题
        await spider.web_await_input_text(css=".titleInput .el-input__wrapper .el-input__inner", text=opt.title)
        num += 1
        print(num, "输入标题                 :")

        # 输入描述
        await spider.web_await_input_text(css=".topic-container", text=opt.text)
        num += 1
        print(num, "输入描述                 :")

        # 添加地点
        pass

        # 权限设置_私密
        await spider.web_await_click(css=".el-radio__label")
        num += 1
        print(num, "权限设置_私密                 :")

        # 发布_按钮点击
        await spider.web_await_click(css=".publishBtn")
        num += 1
        print(num, "发布_按钮点击                 :")

        # 判断_是否_成功
        await spider.web_await_css(css=".btn-content")
        html = await page.content()
        num += 1
        print(num, "成功:发布内容---xiaohongshu")

        await __.tool_await(0.1)
        await __.tool_await(9999)
        await spider.browser.close()
        print("成功:关闭浏览器---xiaohongshu")


    asyncio.get_event_loop().run_until_complete(aaa())



class color2():
    name = 111
    age = 222

    def __getinitargs__(self):
        pass

    def __getstate__(self):
        pass

    def __class_getitem__(cls, item):
        pass

    def __set_name__(self, owner, name):
        pass

    def __module__(self):
        pass

    def __new__(cls, *args, **kwargs):
        pass

    def __file__(self):
        pass

    def __annotations__(self):
        pass

    def __prepare__(cls, name, bases, **kwds):
        return {'__annotations__': {}}

    def __init__(self, instance_attr):
        super().__setattr__(111, 222)
        print("111                 :", 111)
        self.instance_attr = instance_attr

    def __str__(self):
        return f"Color2(name={self.name}, age={self.age})"

    def __repr__(self):
        return f"Color2(name={self.name}, age={self.age})"

    def __class__(self):
        return 1111111


class color2():
    name = 111
    age = 222


print(color2)



# 基础元类
class class_base(type):
    def __str__(self):
        # 遍历所有的类属性
        my_str = ""
        for key, value in self.__dict__.items():
            # print("           key:", key, "        value:", value, )
            if (not key.startswith('__')) and not (key.endswith('__')):
                my_str += f'{key}:{value},'
        return "{" + my_str + "}"


class MyClass(metaclass=class_base):
    name = 111
    age = 111
    aaa = 111


print("2222                 :", MyClass)



import win32api
import win32con
import win32gui

task_bar_handle = win32gui.FindWindow(None, "web - Google Chrome")

# 设置任务栏窗口的风格为隐藏
style = win32gui.GetWindowLong(task_bar_handle, win32con.GWL_STYLE)
print("style                 :", style)
style &= ~win32con.WS_VISIBLE
print("style                 :", style)
aaa1=win32gui.SetWindowLong(task_bar_handle, win32con.GWL_STYLE, style)
print("aaa1                 :", aaa1)
# 更新任务栏窗口
aaa2 = win32gui.ShowWindow(task_bar_handle, win32con.SW_HIDE)

print("aaa2                 :", aaa2)




import win32gui
import win32con
import os


def wind_find_name_all(name):
    def callback(hwnd, param):
        # print("param                 :" ,  111   )
        text = win32gui.GetWindowText(hwnd)
        class_name = win32gui.GetClassName(hwnd)
        left, top, right, bottom = win32gui.GetWindowRect(hwnd)
        style = win32gui.GetWindowLong(hwnd, win32con.GWL_STYLE)
        # print(f"Window handle: {hwnd}")
        # print(f"Window title: {text}")
        # print(f"Window class: {class_name}")
        # print(f"Window position: ({left}, {top}, {right}, {bottom})")
        # print(f"Window style: {hex(style)}")
        # print()
        # print("name                 :", name, text)
        if (name in text):
            obj1 = dict(text=text, class_name=class_name, hwnd=hwnd)
            param.append(obj1)
        return True

    param = []
    win32gui.EnumWindows(callback, param)
    return param


if __name__ == '__main__':
    print("111                 :", wind_find_name_all("Goog"))



# class calc:
#     val="ccc"
#     def __init__(self):
#         self._val=0
#     def __add__(self,other):
#         print(  111111111111111111111 , other  )
#         if isinstance (other,str):
#             self._val=  self._val+ int( other)
#             return    self._val
#         else:
#             self._val=   self._val+ other
#             return    self._val
#
#     def __getitem__(self,item):
#         print(222, item )
#         return self
#
#     @property
#     def a(self):
#         return self
#
#
#     @property
#     def b(self):
#         return self
#
#     def __call__(self,*args,**kwargs):
#         return self
#
#     def __getattr__(self,item):
#         if item in ["a","b","c","d","f","g"]:
#             print(item)
#             return self
#
#
#     def __truediv__(self,item):
#         return self
#
#     def __floordiv__(self,item):
#         return self
#
#
#
#
# c=calc()
# print(      c+111+222   )
# # print(      c+111+"222"   )
# c[""][9999][:][...][:,:]
#
# c.a.b
# c.a.b.c.a.c.b.f.g()
#
# https=www=com=index=baodu=html=calc()
# https//www
#
# # ====================================================
#
#
# def f(*arg):
#     print(arg)
#     if arg == "":
#         ...
#     return f
#
# f("唱歌")("跳舞")


import json

#   已解决raise JSONDecodeError(“Expecting value”, s, err.value) from None              https://blog.csdn.net/yuan2019035055/article/details/127824881
def JSON(xxx):
    # 定义一个 JSON 字符串
    json_string = '{"name": "John Doe", "age": 35, "email": "john.doe@example.com"}'

    # 将 JSON 字符串转换为 Python 字典
    my_dict = json.loads(xxx)
    # print(type(my_dict))

    return my_dict


if __name__ == '__main__':
    xxx = '{"name": "John Doe", "age": 35, "email": "john.doe@example.com"}'
    print("111                 :", JSON(xxx))
    pass



if __name__ == '__main__':
    import astmain_py777.astmain as __  # 本地包

    spider = __.spider.SPIDER
    wind_find_name = __.spider.SPIDER.wind_find_name
    obj1 = wind_find_name("Google")
    print("obj1                 :", obj1)

    import ctypes

    pass
    # ctypes.windll.user32.SetWindowPos(obj1["hwnd"], None, -300, -900+100, 0, 0, 0x0001)
    ctypes.windll.user32.SetWindowPos(obj1["hwnd"], None, 100, 100, 0, 0, 0x0001)
    """
    hwnd 是要移动的窗口的句柄。
    hWndInsertAfter 设为 None 表示不改变窗口的插入顺序。
    x 和 y 设置为 100,表示将窗口的左上角移动到屏幕坐标 (100, 100)。
    cx 和 cy 设为 0 表示不改变窗口的大小。
    uFlags 设为 0x0001 表示只修改窗口的位置,不修改大小。
    """



import asyncio
from pyppeteer import launch

import win32api, win32gui, win32con  # pip  install     pywin32  可能会出现问题_请看README_后端py.md

once = None
# launcher.DEFAULT_ARGS.remove("--enable-automation")
opt_chrome = {
    "devtools": True,
    'userDataDir': r'C:\Users\Administrator\Desktop\userdir',
    # 'executablePath': r'C:\Users\Administrator\AppData\Local\Google\Chrome\Application\chrome.exe',  # 浏览器安装路径   chrome://version
    'executablePath': r'C:\Program Files\Google\Chrome\Application\chrome.exe',  # 浏览器安装路径   chrome://version
    # 'executablePath': r'C:\Users\Administrator\AppData\Local\360ChromeX\Chrome\Application\360ChromeX.exe',  # 浏览器安装路径   chrome://version
    'headless': False,
    'dumpio': True,  # 减少内存消耗   set_launch = {}
    # "ignoreDefaultArgs": ["--enable-automation"],
    'args': [
        # "--headless",
        "--mute-audio",  # 禁音
        '--no-sandbox',  # 关闭沙盒
        # '--disable-gpu',  # 禁用 GPU 硬件加速
        # '--log-level=3',  # 日志等级
        # '--disable-infobars',  # 禁用提示栏 --开启后页面加载不了
        '--window-size=1600,900',  # 屏幕大小
        '--window-position=100,100',  # 桌面位置
        "--user-agent=Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.97 Safari/537.36",
    ],
}


async def wind_show(win, isshow=1):
    win32gui.ShowWindow(win["hwnd"], isshow)


def wind_find_name(name):
    def callback(hwnd, param):
        # print("param                 :" ,  111   )
        text = win32gui.GetWindowText(hwnd)
        class_name = win32gui.GetClassName(hwnd)
        left, top, right, bottom = win32gui.GetWindowRect(hwnd)
        style = win32gui.GetWindowLong(hwnd, win32con.GWL_STYLE)
        # print(f"Window handle: {hwnd}")
        # print(f"Window title: {text}")
        # print(f"Window class: {class_name}")
        # print(f"Window position: ({left}, {top}, {right}, {bottom})")
        # print(f"Window style: {hex(style)}")
        # print()
        # print("name                 :", name, text)
        # print("text                 :", text)
        if (name in text):
            obj1 = dict(text=text, class_name=class_name, hwnd=hwnd)
            param.append(obj1)

        return True

    param = []
    win32gui.EnumWindows(callback, param)
    obj1 = param[0]
    print("obj1                 :", obj1)
    return obj1


async def background_task_wind_hide_taskbar_log(opt=111):
    def aaa(name):
        obj1 = wind_find_name(name)
        print("obj1                 :", obj1)
        if obj1:
            # print("obj1                 :", obj1)
            win32gui.SetWindowLong(obj1["hwnd"], win32con.GWL_STYLE, win32gui.GetWindowLong(obj1["hwnd"], win32con.GWL_STYLE) & ~win32con.WS_VISIBLE)

            return True

    for i, ele in enumerate(range(100)):
        # if win32gui.ShowWindow(win32gui.FindWindow(None, "web - Google Chrome"), 0):    return True
        # if win32gui.ShowWindow(win32gui.FindWindow(None, "about:blank - Google Chrome"), 0):    return True
        # if win32gui.ShowWindow(win32gui.FindWindow(None, "about:blank - Google Chrome"), 0):    return True
        # if win32gui.ShowWindow(win32gui.FindWindow(None, "web - Google Chrome"), 0):    return True
        # if win32gui.ShowWindow(win32gui.FindWindow(None, "小红书创作服务平台 - Google Chrome"), 0):    return True
        if aaa("Google"):    return True
        # if aaa("about:blank - Google Chrome"):    return True
        # if aaa("小红书创作服务平台 - Google Chrome"):    return True

        await asyncio.sleep(0.1)


class SPIDER:
    wind_find_name = wind_find_name

    def __init__(self, *args, **kwargs):
        pass

    # 创建浏览器
    async def create_browser(self, is_hide=True):
        # 初始化页面
        self.browser = await launch(opt_chrome)
        self.pages = await self.browser.pages()
        # self.page = self.pages[0]
        self.page = await self.browser.newPage()
        await self.page.evaluate('''() => { Object.defineProperty(navigator, 'webdriver', {get: () => undefined})}''')  # evaluateOnNewDocument
        # await self.page.evaluate('''() => { Object.defineProperty(webdriver, 'webdriver', {get: () => false})}''')  # evaluateOnNewDocument

        # 反扒库
        self.web = self.page
        await self.web.setViewport({"width": 1920, "height": 1080})
        # if is_hide: await background_task_wind_hide_taskbar_log()  # 隐藏任务栏目图标
        # await stealth(self.web)

        # 使用拦截器时会有问题
        # await self.page.setRequestInterception(True)  # 拦截
        # self.page.on('request', lambda req: asyncio.ensure_future(intercept(req)))
        return self

    # 页面跳转
    async def web_goto(self, url=""):
        await self.web.goto(url)
        await self.web.waitForSelector("html", timeout=10 * 1000)
        await self.web.evaluate(""" document.title = 'web';  """)
        return self

    # 页面跳转_设置cookies
    async def web_goto_set_cookie(self, url="", cookie={}, is_hide=True):
        await self.web_set_cookies(cookie)  # 设置cookie
        # print("000                waitForSelector :", 111)
        await self.web.goto(url, {"timeout": 9 * 1000})

        # if is_hide: await background_task_wind_hide_taskbar_log()  # 隐藏任务栏目图标
        # await self.web.waitForSelector("div", timeout=5000)
        # print("111                waitForSelector :", 111)
        await self.web.evaluate('''() => { Object.defineProperty(navigator, 'webdriver', {get: () => undefined})}''')  # evaluateOnNewDocument
        await self.web.evaluate(""" document.title = 'web';  """)
        self.win = wind_find_name("Google")
        # await wind_show(self.win, 0)
        print("self.win                 :", self.win)

        print("成功:页面跳转设置cookies--", "web_goto_set_cookie", url)
        return self
        pass

    # 等待css
    async def web_await_css(self, css="body", timeout=10 * 1000):
        # await wind_show(self.win, 1)
        try:
            await self.web.waitForSelector(css, timeout=timeout)
            await self.web.querySelector(css)
            return self
        except Exception as error:
            print("error web_await_css            :", css, str(error))

    # 点击元素
    async def web_await_click(self, css="body", timeout=10 * 1000):
        # await wind_show(self.win, 1)
        try:
            await self.web.waitForSelector(css, timeout=timeout)
            await self.web.click(css)
            # print("isok  web_await_click          :", css)
            return self
        except Exception as error:
            print("error web_await_click          :", css, str(error))

    # input上传文件
    async def web_await_input_files(self, css="body", files=[], timeout=10 * 1000):
        try:
            # await wind_show(self.win, 1)
            await self.web.waitForSelector(css, timeout=timeout)
            input_element = await self.web.querySelector(css)
            # await input_element.uploadFile(r"C:\Users\Administrator\Desktop\111.png", r"C:\Users\Administrator\Desktop\222.png")
            await input_element.uploadFile(*files)
            print("图片上传完成                 :", 111)
        except Exception as error:
            print("error web_await_input_files          :", css, str(error))

    # input输入文字
    async def web_await_input_text(self, css="body", text="hello world", timeout=10 * 1000):
        try:
            await self.web.waitForSelector(css, timeout=11111)
            await self.web.click(css)
            await self.web.type(css, text), await asyncio.sleep(1)
        except Exception as error:
            print("error web_await_input_files          :", css, str(error))

    # 设置cookies
    async def web_set_cookies(self, cookies):
        if type(cookies) == dict:
            for key in cookies:
                # print("key            :", key)
                await self.web.setCookie({'name': key, 'value': cookies[key], 'domain': '.xiaohongshu.com'})

        if type(cookies) == list:
            for ele in cookies:
                await self.web.setCookie(ele)


async def spider_pyppeteer(x=1, y=1):
    """ EXPLAIN :   启动一个浏览器窗口
        EXAMPLE :
spider = await spider_pyppeteer()  #通常开发_浏览器位置,默认
spider = await __.spider.spider_pyppeteer(**dict( x=100, y=100))    #通常开发_浏览器位置,默认
spider = await __.spider.spider_pyppeteer(**dict(x=99999, y=99999)) #通常开发_浏览器位置,移动到屏幕外
page = spider.page
    """

    global once

    # if once is None:
    #     print("111---spider---实例初始化       :")
    #     once = await SPIDER().create_browser()
    #     return once
    # else:
    #     print("222---spider---实例已经存在     :")
    #     return once

    opt_chrome["args"] = [
        # "--headless",
        "--mute-audio",  # 禁音
        '--no-sandbox',  # 关闭沙盒
        '--disable-gpu',  # 禁用 GPU 硬件加速
        # '--log-level=3',  # 日志等级
        '--disable-infobars',  # 禁用提示栏 --开启后页面加载不了
        '--start-maximized',
        '--window-size=1600,900',  # 屏幕大小
        f'--window-position={x},{y}',  # 桌面位置
        "--user-agent=Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.97 Safari/537.36",
    ]
    once = await SPIDER().create_browser()
    print("成功:启动浏览器---spider                 位置", x, y)
    return once



def type_vars():
    class Person:
        title = "title111"

        def __init__(self, name, age):
            self.name = name
            self.age = age

        @property
        def is_adult(self):
            return self.age >= 18

    p = Person("Alice", 25)
    print("1 p                  :", p)  # <__main__.Person object at 0x0000015E20FECFD0>
    print("2 p.is_adult         :", p.is_adult)  # True
    print("3 vars(p)            :", vars(p))  ## {'name': 'Alice', 'age': 25}
    print("4 vars(Person)       :", vars(Person))  ## {'__module__': '__main__', 'title': 'title111', '__init__': <function Person.__init__ at 0x0000022FCD71F670>, 'is_adult': <property object at 0x0000022FCD72F860>,
    print("5 type(vars(Person)) :", type(vars(Person)))  ## <class 'mappingproxy'>
    print("6 type(vars(Person)) :", vars(Person)['species'])


if __name__ == '__main__':
    type_vars()



import os
import multiprocessing as mp
from typing import List, Optional


def find_file(root_dir, filename):
    """在给定的根目录中搜索指定的文件名,并返回文件的绝对路径。 如果找到文件,返回文件路径;否则返回 None。 """
    file_path = os.path.join(root_dir, filename)
    if os.path.exists(file_path):
        return file_path
    for dirpath, dirnames, filenames in os.walk(root_dir):
        for file in filenames:
            if file.lower() == filename.lower():
                return os.path.join(dirpath, file)
    return None


def fs_find_file(dirs: List[str], filenames: List[str]) -> Optional[str]:
    """ EXPLAIN :
        根,目录,搜索,文件名,如果找到任何文件,则返回文件的绝对路径,否则返回 None。
        EXAMPLE :  
        dirs = ['C:\\Program Files (x86)', 'C:\\Program Files', 'C:\\']
        filenames = ['chrome.exe', 'notepad.exe']
        file_path = fs_find_file(dirs, filenames)
    """
    results = []
    with mp.Pool(processes=len(dirs)) as pool:
        # 使用 apply_async 并行处理每个根目录和文件名的搜索任务
        for root_dir in dirs:
            for filename in filenames:
                results.append(pool.apply_async(find_file, args=(root_dir, filename)))
        # 等待所有任务完成,并返回找到的第一个文件路径
        for result in results:
            file_path = result.get()
            if file_path is not None:
                return file_path
    return "None"


if __name__ == '__main__':
    dirs = ['C:\\Program Files (x86)', 'C:\\Program Files', 'C:\\']
    filenames = ['chrome.exe', 'notepad.exe']
    file_path = fs_find_file(dirs, filenames)
    if file_path:
        print(f'Found file at: {file_path}')
    else:
        print(f'Files not found.')

# 不要使用列表推导式#不要使用lambda表达式#运行速度在快一点,我写好正文注释
